@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.11';
+our $VERSION = '2.12';
 
 my $log;
 my $bcmd;
@@ -75,6 +75,7 @@ sub options {
         "T|selftest"    => \$opts{selftest},
         "D|dispatch"    => \$opts{dispatch},
         "t|tester=s@"   => \$opts{testers},
+        "X|nocache"     => \$opts{nocache},
         "s|setup"       => \$opts{setup},
         "h|help"        => \$opts{help},
     );
@@ -101,8 +102,19 @@ sub is_win {
 sub brew_info {
     my $self = shift;
     my $log = $log->child('brew_info');
-    my $brew_info = $bcmd->info;
+
+    my $brew_info;
+
+    if ($self->{args}{nocache}){
+        # don't use cached info
+        $brew_info = $bcmd->info;
+    }
+    else {
+        $brew_info = $bcmd->info_cache;
+    }
+
     $log->_6("brew info set to:\n$brew_info") if $brew_info;
+
     return $brew_info;
 }
 sub perls_available {
@@ -128,7 +140,7 @@ sub instance_install {
             $timeout = $self->{args}{timeout};
         }
         else {
-            $timeout = 300;
+            $timeout = 600;
         }
     }
 
@@ -209,6 +221,7 @@ sub instance_install {
         for my $ver (@new_installs) {
             $log->_0( "installing $ver..." );
             $log->_5( "...using cmd: $install_cmd" );
+            undef $@;
             eval {
                 local $SIG{ALRM} = sub {
                     die "$ver failed to install... skipping"
@@ -224,6 +237,7 @@ sub instance_install {
                 next;
             }
         }
+        $bcmd->info_cache if $self->{args}{info_cache};
     }
     else {
         $log->_5("using existing versions only, nothing to install");
@@ -274,6 +288,7 @@ sub instance_remove {
         }
     }
 
+    $bcmd->info_cache if $self->{args}{info_cache};
     $log->_4("removal of existing perl installs complete...");
 }
 sub revdep {
@@ -452,6 +467,7 @@ Local usage options:
 -i | --install  Number portion of an available perl version according to "*brew available". Multiple versions can be sent in at once
 -S | --save     By default, we save only FAIL logs. This will also save the PASS logs
 -N | --notest   Do not run tests. Allows you to --remove and --install without testing
+-X | --nocache  By default, we cache the results of 'perlbrew available'. Disable with this flag.
 
 Network dispatching options:
 
@@ -859,7 +875,8 @@ sub _validate_opts {
 
     my @valid_args = qw(
         on o new n remove r revdep R plugin p args a debug d install i help h
-        N notest setup s legacy l selftest T t testers S save D dispatch
+        N notest setup s legacy l selftest T t testers S save D dispatch X
+        nocache
     );
 
     my $bad_opt = 0;
@@ -897,10 +914,11 @@ L<here|https://metacpan.org/pod/distribution/Test-BrewBuild/bin/bbtester>, or
 browse through the L<Test::BrewBuild::Tutorial> for network testing.
 
 This module provides you the ability to perform your unit tests across all of
-your Perlbrew (Unix) or Berrybrew (Windows) Perl instances.
+your L<Perlbrew|http://perlbrew.pl> (Unix) or L<Berrybrew|https://github.com/stevieb9/berrybrew>
+(Windows) Perl instances.
 
-For Windows, you'll need to install Berrybrew (see L<SEE ALSO> for details).
-For Unix, you'll need Perlbrew.
+For Windows, you'll need to install B<L<Berrybrew|https://github.com/stevieb9/berrybrew>>, 
+and for Unix, you'll need B<L<Perlbrew|http://perlbrew.pl>>.
 
 It allows you to remove and reinstall on each test run, install random versions
 of perl, or install specific versions.
