@@ -12,7 +12,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.11';
+our $VERSION = '2.12';
 
 $| = 1;
 
@@ -55,8 +55,8 @@ sub dispatch {
         $log->_6("no --testers passed in, and failed to fetch testers from " .
                  "config file, croaking"
         );
-        croak "dispatch requires clients sent in or config file which " .
-              "isn't found\n";
+        croak "dispatch requires testers sent in or config file, which " .
+              "can't be found. Run \"bbdispatch -h\" for help.\n";
     }
     else {
         $log->_7("working on testers: " . join ', ', @$testers);
@@ -215,18 +215,25 @@ sub _fork {
             my $repo_link;
 
             if (! $repo){
-                my $git = Test::BrewBuild::Git->new;
+                my $git = Test::BrewBuild::Git->new(debug => $self->{debug});
+                $log->_5("repo not sent in, attempting to set via Git");
                 $repo_link = $git->link;
-                $log->_5("repo not sent in, set to: $repo_link via Git");
+
+                if ($repo_link){
+                    $log->_5("repo set to $repo_link from Git");
+                }
+                else {
+                    $log->_7("\$repo_link could not be set, we're about to fail...");
+                }
             }
             else {
                 $repo_link = $repo;
-                $log->_5("repo set to: $repo_link");
+                $log->_5("repo sent in, and set to: $repo_link");
             }
 
             if (! $repo_link){
-                $log->_0("repo '$repo_link' not found, croaking");
-                croak "\nno repository found, can't continue\n";
+                $log->_0("no repository supplied and not in a repo dir... croaking");
+                croak "\nno repository found, and none sent in via param, can't continue...\n";
             }
             $socket->send($repo_link);
 
