@@ -13,7 +13,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.11';
+our $VERSION = '2.12';
 
 $| = 1;
 
@@ -31,7 +31,7 @@ sub new {
     my $log_file = \$self->{log};
 
     if ($self->{logfile}){
-       $log_file = Test::BrewBuild->workdir ."/bbtester_parent.log";
+        $log_file = Test::BrewBuild->workdir ."/bbtester_parent.log";
     }
 
     $log->file($log_file) if ! $self->{log_to_stdout};
@@ -267,7 +267,7 @@ sub listen {
         $log->_7("received repo: $repo");
 
         if ($repo){
-            my $git = Test::BrewBuild::Git->new;
+            my $git = Test::BrewBuild::Git->new(debug => $self->{debug});
 
             if (-d $git->name($repo)){
                 chdir $git->name($repo) or die $!;
@@ -427,6 +427,25 @@ Note that by default, the working directory is C<~/brewbuild> on all platforms.
 
 Returns a new C<Test::BrewBuild::Tester> object.
 
+Parameters:
+
+    debug => $level
+
+Integer, optional. Debug level from least verbose (0) to maximum verbosity (7).
+
+    stdout => $bool
+
+Integer, optional. By default, we return the test log/debug output with the
+results of the test run. Set this to true (1) to disable this, and have the
+tester print its output directly to STDOUT instead.
+
+    logfile => $bool
+
+Integer, optional. Set this to true (1) and we'll write all tester output to a
+log file. The parent tester server will create a C<$workdir/bbtester_parent.log>
+file (where C<$workdir> is C<~/brewbuild> by default), and the children tester
+runners will all log to C<$workdir/bbtester_child.log>.
+
 =head2 start
 
 Starts the tester, and puts it into the background.
